From 5267dce21023802818b0c0c16ba2ca47c146e1b5 Mon Sep 17 00:00:00 2001
From: Unknwon <u@gogs.io>
Date: Fri, 11 Mar 2016 05:11:58 -0500
Subject: [PATCH] Fix ref comment from commit create empty feed

---
 README.md               | 2 +-
 gogs.go                 | 2 +-
 models/issue_comment.go | 8 +++++---
 modules/base/tool.go    | 1 +
 templates/.VERSION      | 2 +-
 5 files changed, 9 insertions(+), 6 deletions(-)

diff --git a/README.md b/README.md
index f53f97ed61..dff0393c6a 100644
--- a/README.md
+++ b/README.md
@@ -3,7 +3,7 @@ Gogs - Go Git Service [![Build Status](https://travis-ci.org/gogits/gogs.svg?bra
 
 ![](https://github.com/gogits/gogs/blob/master/public/img/gogs-large-resize.png?raw=true)
 
-##### Current version: 0.9.3
+##### Current version: 0.9.4
 
 | Web | UI  | Preview  |
 |:-------------:|:-------:|:-------:|
diff --git a/gogs.go b/gogs.go
index 933d923024..3616431cf9 100644
--- a/gogs.go
+++ b/gogs.go
@@ -17,7 +17,7 @@ import (
 	"github.com/gogits/gogs/modules/setting"
 )
 
-const APP_VER = "0.9.3.0309"
+const APP_VER = "0.9.4.0311"
 
 func init() {
 	runtime.GOMAXPROCS(runtime.NumCPU())
diff --git a/modules/base/tool.go b/modules/base/tool.go
index 45d0aea5bc..a426ca99b0 100644
--- a/modules/base/tool.go
+++ b/modules/base/tool.go
@@ -97,6 +97,7 @@ func GetRandomString(n int, alphabets ...byte) string {
 }
 
 // http://code.google.com/p/go/source/browse/pbkdf2/pbkdf2.go?repo=crypto
+// FIXME: use https://godoc.org/golang.org/x/crypto/pbkdf2?
 func PBKDF2(password, salt []byte, iter, keyLen int, h func() hash.Hash) []byte {
 	prf := hmac.New(h, password)
 	hashLen := prf.Size()
diff --git a/templates/.VERSION b/templates/.VERSION
index 572d3528cc..c0c0b96224 100644
--- a/templates/.VERSION
+++ b/templates/.VERSION
@@ -1 +1 @@
-0.9.3.0309
\ No newline at end of file
+0.9.4.0311
\ No newline at end of file
diff --git a/models/issue_comment.go b/models/issue_comment.go
index ef890fd2fc..f0cc6188a0 100644
--- a/models/issue_comment.go
+++ b/models/issue_comment.go
@@ -202,9 +202,11 @@ func createComment(e *xorm.Session, opts *CreateCommentOptions) (_ *Comment, err
 		}
 	}
 
-	// Notify watchers for whatever action comes in
-	if err = notifyWatchers(e, act); err != nil {
-		return nil, fmt.Errorf("notifyWatchers: %v", err)
+	// Notify watchers for whatever action comes in, ignore if no action type
+	if act.OpType > 0 {
+		if err = notifyWatchers(e, act); err != nil {
+			return nil, fmt.Errorf("notifyWatchers: %v", err)
+		}
 	}
 
 	return comment, nil